# oriloc
本库用于定位

oriloc主要包括四个函数：<br/>
1、distance 用于求两点距离；<br/>
2、tria 用于三角定位；<br/>
3、cir 用于求两个圆交点；<br/>
4、angle 用于两点角度定位；<br/>


This package is used for location

oriloc includes four functions:<br/>
1. "distance" is used to get the distance between two points;<br/>
2. "tria" is used for triangulation;<br/>
3. "cir" is used to get the intersection of two circles;<br/>
4. "angle" is used for two-point angle positioning.